import subprocess

from cryptsetup import *

##############################################################################

class CryptsetupLuks(Cryptsetup):
  Name_ = 'Cryptsetup-luks'

  def acquire(self):
    """Create a dm-crypt mapping with luks"""
    self._acquire((self._checkName, self._checkDevice), 
        (self.Exe_, 'luksOpen', self.device_, self.name_))

  def release(self):
    """Remove the dm-crypt mapping"""
    self._release((self._checkDevice,),
        (self.Exe_, 'luksClose', self.name_))

  def uuid(self):
    """Get UUID of luks partition"""
    args = (self.Exe_, 'luksUUID', self.device_)
    if not self._commonCmd((self._checkDevice,), args):
      return "<uuid>"
    proc = subprocess.Popen(args, executable=self.Exe_,
        stdout=subprocess.PIPE, stderr=subprocess.PIPE)
    (out, err) = proc.communicate()
    self.handleReturn(proc.returncode, err.splitlines())
    return out.splitlines()[0].strip()

  def isLuks(self):
    """Check if this partition has a luks header"""
    args = (self.Exe_, 'isLuks', self.device_)
    if not self._commonCmd((self._checkDevice,), args):
      return False
    proc = subprocess.Popen(args, executable=self.Exe_,
        stdout=subprocess.PIPE, stderr=subprocess.PIPE)
    (out, err) = proc.communicate()
    if proc.returncode == 0:
      return True
    else:
      return False

##############################################################################

def isLuks(device):
  return CryptsetupLuks(device=device).isLuks()

##############################################################################

def uuid(device):
  return CryptsetupLuks(device=device).uuid()

##############################################################################

if __name__ == '__main__':
  a = CryptsetupLuks('/dev/sda2', 'tmp')
  a.debug(True)
  a.acquire()
  a.release()
  print '"' + a.uuid() + '"'
  print a.isLuks()
