import os
import subprocess

from command import Command
from exception import *

##############################################################################

class Losetup(Command):
  Name_ = 'Losetup'
  Exe_ = 'losetup'
  def __init__(self, file='', loop_device='', cleanup=False):
    Command.__init__(self, cleanup)
    self.file_ = file
    self.loop_device_ = loop_device

  def __str__(self):
    return "%s: \"%s\" on \"%s\"" % (self.Name_, self.file_, self.loop_device_)

  def _checkLoopDevice(self):
    if not self.loop_device_:
      self.findNext()
    if not os.path.exists(self.loop_device_):
      raise CmdBadArgException(self.Name_, "loop device \"%s\" does not exit" % self.loop_device_)

  def _checkFile(self):
    if not self.file_:
      raise CmdBadArgException(self.Name_, 'no fille given')
    if not os.path.exists(self.file_):
      raise CmdBadArgException(self.Name_, "file \"%s\" does not exist" % self.file_)

  def findNext(self):
    """Find next free loop device"""
    proc = subprocess.Popen((self.Exe_, '-f'),
        executable='losetup', stdout=subprocess.PIPE, stderr=subprocess.PIPE)
    (out, err) = proc.communicate()
    self.handleReturn(proc.returncode, err.splitlines())
    self.loop_device = out.splitlines()[0]

  def acquire(self):
    """Set up the loop device"""
    self._acquire((self._checkLoopDevice, self._checkFile),
        (self.Exe_, self.loop_device_, self.file_))

  def release(self):
    """Delete the loop device"""
    self._release((self._checkLoopDevice,),
        (self.Exe_, '-d', self.loop_device_))

  def start(self):
    self.acquire()

  def stop(self):
    self.release()

##############################################################################

def startDevice(file, loop_device=''):
  return Losetup(file, loop_device, cleanup=False).acquire()

##############################################################################

def stopDevice(loop_device):
  return Losetup(loop_device=loop_device, cleanup=False).release()

##############################################################################

def findNextDevice():
  return Losetup().findNext()

##############################################################################

if __name__ == '__main__':
  a = Losetup('testfile', '/dev/loop0')
  try:
    a.start()
  except CmdException, e:
    print e

  try:
    a.stop()
  except CmdException, e:
    print e

  try:
    startDevice('/boot/map')
  except CmdException, e:
    print e
