import os

from command import Command
from exception import *

##############################################################################

class Mount(Command):
  Name_ = 'Mount'
  Exe_ = 'mount'
  def __init__(self, src='', dst='', opt='defaults', type='', cleanup=False):
    Command.__init__(self, cleanup)
    self.src_ = src
    self.dst_ = dst
    if isinstance(opt, str):
      self.opt = opt.split(',')
    else:
      self.opt = opt
    self.type_ = type

  def __str__(self):
    return "%s: \"%s\" on \"%s\" with options %s" % (self.Name_, self.src_, self.dst_, self.opt)

  def _checkMountpoint(self):
    if not self.dst_:
      raise CmdBadArgException(self.Name_, 'no mountpoint given')
    if not os.path.exists(self.dst_):
      raise CmdBadArgException(self.Name_, 'mountpoint \"%s\" does not exist' % self.dst_)

  def _checkDevice(self):
    if not self.src_:
      raise CmdBadArgException(self.Name_, 'no src argument given')
    if not os.path.exists(self.src_):
      raise CmdBadArgException(self.Name_, 'src \"%s\" does not exist' % self.src_)

  def acquire(self):
    """Mount the specified device"""
    self._acquire((self._checkMountpoint, self._checkDevice),
        (self.Exe_, self.type_, self.src_, self.dst_, '-o', ','.join(self.opt)))

  def release(self):
    """Umount the specified device"""
    self._release((self._checkMountpoint,), ('umount', self.dst_))

  def mount(self):
    self.acquire()

  def umount(self):
    self.release()

##############################################################################

def mountDevice(src, dst, opt=''):
  Mount(src, dst, opt).acquire()

##############################################################################

def umountDevice(mntpoint):
  Mount(dst=mntpoint).release()

##############################################################################

if __name__ == '__main__':
  a = Mount('/dev/hda1', '/mnt/hda1')
  print a

  try:
    a.mount()
  except CmdException, e:
    print e

  try:
    a.umount()
  except CmdException, e:
    print e
  
  try:
    umountDevice('/mnt/tmp')
  except CmdException, e:
    print e
